@@ -1,5 +1,5 @@
-__version__ = "5.15.0"
-__version_info__ = (5, 15, 0, "", "")
+__version__ = "5.15.2.1"
+__version_info__ = (5, 15, 2.1, "", "")
 
 # PYSIDE-932: Python 2 cannot import 'zipfile' for embedding while being imported, itself.
 # We simply pre-load all imports for the signature extension.
@@ -26,5 +26,5 @@ if sys.version_info[0] == 3:
 
 from .shiboken2 import *
 
-# Trigger signature initialization.
-type.__signature__
+# Trigger signature initialization via __builtins__.
+_init_pyside_extension()
